=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2007-04-11 22:05:16 +0000
+++ bzrlib/diff.py	2007-07-09 07:38:03 +0000
@@ -436,7 +436,7 @@
     has_changes = 0
     for path, file_id, kind in delta.removed:
         has_changes = 1
-        print >>to_file, '=== removed %s %r' % (kind, path.encode('utf8'))
+        print >>to_file, "=== removed %s '%s'" % (kind, path.encode('utf8'))
         old_name = '%s%s\t%s' % (old_label, path,
                                  _patch_header_date(old_tree, file_id, path))
         new_name = '%s%s\t%s' % (new_label, path, EPOCH_DATE)
@@ -444,7 +444,7 @@
                                          new_name, None, None, to_file)
     for path, file_id, kind in delta.added:
         has_changes = 1
-        print >>to_file, '=== added %s %r' % (kind, path.encode('utf8'))
+        print >>to_file, "=== added %s '%s'" % (kind, path.encode('utf8'))
         old_name = '%s%s\t%s' % (old_label, path, EPOCH_DATE)
         new_name = '%s%s\t%s' % (new_label, path,
                                  _patch_header_date(new_tree, file_id, path))
@@ -455,7 +455,7 @@
          text_modified, meta_modified) in delta.renamed:
         has_changes = 1
         prop_str = get_prop_change(meta_modified)
-        print >>to_file, '=== renamed %s %r => %r%s' % (
+        print >>to_file, "=== renamed %s '%s' => %r%s" % (
                     kind, old_path.encode('utf8'),
                     new_path.encode('utf8'), prop_str)
         old_name = '%s%s\t%s' % (old_label, old_path,
@@ -470,7 +470,8 @@
     for path, file_id, kind, text_modified, meta_modified in delta.modified:
         has_changes = 1
         prop_str = get_prop_change(meta_modified)
-        print >>to_file, '=== modified %s %r%s' % (kind, path.encode('utf8'), prop_str)
+        print >>to_file, "=== modified %s '%s'%s" % (kind, path.encode('utf8'),
+                                                     prop_str)
         # The file may be in a different location in the old tree (because
         # the containing dir was renamed, but the file itself was not)
         old_path = old_tree.id2path(file_id)

=== modified file 'bzrlib/tests/test_diff.py'
--- bzrlib/tests/test_diff.py	2007-07-06 12:29:38 +0000
+++ bzrlib/tests/test_diff.py	2007-07-09 07:38:03 +0000
@@ -442,28 +442,31 @@
                                     '\\+new contents\n')
 
     def test_binary_unicode_filenames(self):
-        """Test that contents of files are encoded in UTF-8 when there is a
-        binary file in the diff.
+        """Test that contents of files are *not* encoded in UTF-8 when there
+        is a binary file in the diff.
         """
         # See https://bugs.launchpad.net/bugs/110092.
 
         # This bug isn't triggered with cStringIO.
         from StringIO import StringIO
         tree = self.make_branch_and_tree('tree')
+        alpha, omega = u'\u03b1', u'\u03c9'
+        alpha_utf8, omega_utf8 = alpha.encode('utf8'), omega.encode('utf8')
         self.build_tree_contents(
-            [('tree/binary', chr(0)),
-             ('tree/elephant', '\xc7a trompe \xc3\xa9norm\xc3\xa9ment.\n')])
-        tree.add(['binary'], ['file-id'])
-        tree.add(['elephant'], ['file-id-2'])
+            [('tree/' + alpha, chr(0)),
+             ('tree/' + omega,
+              ('The %s and the %s\n' % (alpha_utf8, omega_utf8)))])
+        tree.add([alpha], ['file-id'])
+        tree.add([omega], ['file-id-2'])
         diff_content = StringIO()
         show_diff_trees(tree.basis_tree(), tree, diff_content)
         diff = diff_content.getvalue()
-        self.assertContainsRe(diff, "=== added file 'binary'")
+        self.assertContainsRe(diff, r"=== added file '%s'" % alpha_utf8)
         self.assertContainsRe(
-            diff, "Binary files a/binary.*and b/binary.* differ\n")
-        self.assertContainsRe(diff, "=== added file 'elephant'")
-        self.assertContainsRe(diff, "--- a/elephant")
-        self.assertContainsRe(diff, "\\+\\+\\+ b/elephant")
+            diff, "Binary files a/%s.*and b/%s.* differ\n" % (alpha_utf8, alpha_utf8))
+        self.assertContainsRe(diff, r"=== added file '%s'" % omega_utf8)
+        self.assertContainsRe(diff, r"--- a/%s" % (omega_utf8,))
+        self.assertContainsRe(diff, r"\+\+\+ b/%s" % (omega_utf8,))
 
 
 class TestPatienceDiffLib(TestCase):

